# onnx_predictor example

These examples show how to convert to and use a ONNX model with the *biotrainer Inferencer* class.

Find more information about the ONNX format here:
* https://onnx.ai/
* https://pytorch.org/docs/stable/onnx.html
